@@ -3,21 +3,21 @@
 #############################################################################
 ##
 ## This file is part of Taurus, a Tango User Interface Library
-## 
+##
 ## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
+##
 ## Taurus is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU Lesser General Public License as published by
 ## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## Taurus is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU Lesser General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU Lesser General Public License
 ## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
@@ -33,6 +33,7 @@ __docformat__ = "restructuredtext"
 import time
 import threading
 import PyTango
+import numpy
 
 from taurus import Factory, Manager
 from taurus.core.taurusattribute import TaurusAttribute, TaurusStateAttribute
@@ -48,42 +49,42 @@ class TangoAttribute(TaurusAttribute):
 
     # helper class property that stores a reference to the corresponding factory
     _factory = None
-    
+
     def __init__(self, name, parent, **kwargs):
 
         # the last attribute value
         self.__attr_value = None
-        
+
         # the last attribute error
         self.__attr_err = None
-        
+
         # the last time the attribute was read
         self.__attr_timestamp = 0
-        
+
         # the change event identifier
         self.__chg_evt_id = None
 
         # reference to the configuration object
         self.__attr_config = None
-        
+
         # current event subscription state
         self.__subscription_state = SubscriptionState.Unsubscribed
         self.__subscription_event = threading.Event()
 
         self.call__init__(TaurusAttribute, name, parent, **kwargs)
 
-    def __getattr__(self,name):
+    def __getattr__(self, name):
         return getattr(self._getRealConfig(), name)
-    
+
     def _getRealConfig(self):
         """ Returns the current configuration of the attribute."""
 
         if self.__attr_config is None:
             cfg_name = "%s?configuration" % self.getFullName()
-            from taurus.core.tango import TangoConfiguration # @todo...
+            from taurus.core.tango import TangoConfiguration  # @todo...
             self.__attr_config = TangoConfiguration(cfg_name, self)
         return self.__attr_config
-        
+
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # TaurusModel necessary overwrite
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
@@ -99,11 +100,11 @@ class TangoAttribute(TaurusAttribute):
         attr_value.value = self.encode(value)
         op = WriteAttrOperation(self, attr_value)
         return op
-    
+
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # PyTango connection
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-    
-    
+    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+
     def isNumeric(self, inc_array=False):
         cfg = self._getRealConfig()
         if not cfg:
@@ -111,10 +112,10 @@ class TangoAttribute(TaurusAttribute):
             return False
         if inc_array and not self.isScalar():
             return False
-        
+
         type = cfg.getType()
         return PyTango.is_numerical_type(type, inc_array=inc_array)
-    
+
     def isInteger(self, inc_array=False):
         cfg = self._getRealConfig()
         if not cfg:
@@ -136,7 +137,7 @@ class TangoAttribute(TaurusAttribute):
 
         type = cfg.getType()
         return PyTango.is_float_type(type, inc_array=inc_array)
-    
+
     def isBoolean(self, inc_array=False):
         cfg = self._getRealConfig()
         if not cfg:
@@ -144,46 +145,50 @@ class TangoAttribute(TaurusAttribute):
             return False
         if inc_array and not self.isScalar():
             return False
-        
+
         type = cfg.getType()
         if inc_array:
             return type in (DataType.DevBoolean, DataType.DevVarBooleanArray)
         else:
             return type == DataType.DevBoolean
-    
+
     def isState(self):
         cfg = self._getRealConfig()
         if not cfg:
             self.warning("attribute does not contain information")
             return False
         return cfg.getType() == DataType.DevState
-        
-    def getDisplayValue(self,cache=True):
+
+    def getDisplayValue(self, cache=True):
         attrvalue = self.getValueObj(cache=cache)
         if not attrvalue:
             return None
         v = attrvalue.value
-            
+
         return self.displayValue(v)
-        
+
     def encode(self, value):
         """Translates the given value into a tango compatible value according to
         the attribute data type"""
-        
+
         attrvalue = None
-        
+
         if self._getRealConfig() is None:
             self.warning("attribute does not contain information")
             return value
-            
+
         fmt = self.getDataFormat()
         type = self.getType()
         if fmt == PyTango.SCALAR:
-            if PyTango.is_float_type(type):
+            if type == DataType.DevDouble:
                 attrvalue = float(value)
+            elif type == DataType.DevFloat:
+                # We encode to float, but rounding to Tango::DevFloat precision
+                # see: http://sf.net/p/sardana/tickets/162
+                attrvalue = float(numpy.float32(value))
             elif PyTango.is_int_type(type):
                 #attrvalue = int(value)
-                attrvalue = long(value) #changed as a partial workaround to a problem in PyTango writing to DevULong64 attributes (see ALBA RT#29793)
+                attrvalue = long(value)  #changed as a partial workaround to a problem in PyTango writing to DevULong64 attributes (see ALBA RT#29793)
             elif type == DataType.DevBoolean:
                 try:
                     attrvalue = bool(int(value))
@@ -200,12 +205,12 @@ class TangoAttribute(TaurusAttribute):
         else:
             attrvalue = str(value)
         return attrvalue
-    
+
     def decode(self, attr_value):
         """Decodes a value that was received from PyTango into the expected 
         representation"""
         return attr_value
-    
+
     def write(self, value, with_read=True):
         """ Write the value in the Tango Device Attribute """
         try:
@@ -244,7 +249,7 @@ class TangoAttribute(TaurusAttribute):
 
     def poll(self, **kwargs):
         """ Notify listeners when the attribute has been polled"""
-        single = kwargs.get('single',True)
+        single = kwargs.get('single', True)
         try:
             if single:
                 self.read(cache=False)
@@ -266,7 +271,7 @@ class TangoAttribute(TaurusAttribute):
         else:
             self.__subscription_event.set()
             self.fireEvent(TaurusEventType.Periodic, self.__attr_value)
-            
+
     def read(self, cache=True):
         """ Returns the current value of the attribute.
             if cache is set to True (default) or the attribute has events 
@@ -275,7 +280,7 @@ class TangoAttribute(TaurusAttribute):
         curr_time = time.time()
 
         if cache:
-            dt = (curr_time - self.__attr_timestamp)*1000
+            dt = (curr_time - self.__attr_timestamp) * 1000
             if dt < self.getPollingPeriod():
                 if self.__attr_value is not None:
                     return self.__attr_value
@@ -286,7 +291,7 @@ class TangoAttribute(TaurusAttribute):
             try:
                 dev = self.getParentObj()
                 v = dev.read_attribute(self.getSimpleName())
-                self.__attr_value, self.__attr_err, self.__attr_timestamp = self.decode(v), None, curr_time 
+                self.__attr_value, self.__attr_err, self.__attr_timestamp = self.decode(v), None, curr_time
                 return self.__attr_value
             except PyTango.DevFailed, df:
                 self.__attr_value, self.__attr_err, self.__attr_timestamp = None, df, curr_time
@@ -299,15 +304,15 @@ class TangoAttribute(TaurusAttribute):
                 raise e
         elif self.__subscription_state in (SubscriptionState.Subscribing, SubscriptionState.PendingSubscribe):
             self.__subscription_event.wait()
-            
-    
+
+
         if self.__attr_err is not None:
             raise self.__attr_err
         return self.__attr_value
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # API for listeners
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-    
+    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
     def __fireRegisterEvent(self, listener):
         #fire a first configuration event
@@ -315,11 +320,11 @@ class TangoAttribute(TaurusAttribute):
         #if cfg:
         #    self.fireEvent(TaurusEventType.Config, cfg, listener)
         #else:
-        
+
         #fire a first change event
         try:
             v = self.read()
-            self.fireEvent(TaurusEventType.Change,v, listener)
+            self.fireEvent(TaurusEventType.Change, v, listener)
         except:
             self.fireEvent(TaurusEventType.Error, self.__attr_err, listener)
 
@@ -330,19 +335,19 @@ class TangoAttribute(TaurusAttribute):
             If the listener is already registered nothing happens."""
         cfg = self._getRealConfig()
         cfg.addListener(listener)
-        
+
         listeners = self._listeners
         initial_subscription_state = self.__subscription_state
 
         ret = TaurusAttribute.addListener(self, listener)
         if not ret:
             return ret
-        
+
         assert len(listeners) >= 1
-        
+
         if self.__subscription_state == SubscriptionState.Unsubscribed and len(listeners) == 1:
             self._subscribeEvents()
-        
+
         #if initial_subscription_state == SubscriptionState.Subscribed:
         if len(listeners) > 1 and (initial_subscription_state == SubscriptionState.Subscribed or self.isPollingActive()):
             sm = self.getSerializationMode()
@@ -351,7 +356,7 @@ class TangoAttribute(TaurusAttribute):
             else:
                 self.__fireRegisterEvent((listener,))
         return ret
-        
+
     def removeListener(self, listener):
         """ Remove a TaurusListener from the listeners list. If polling enabled 
             and it is the last element the stop the polling timer.
@@ -360,28 +365,28 @@ class TangoAttribute(TaurusAttribute):
 
         cfg = self._getRealConfig()
         cfg.removeListener(listener)
-        
+
         if not ret:
             return ret
-    
+
         if self.hasListeners():
             return ret
-        
+
         if self.__subscription_state != SubscriptionState.Unsubscribed:
             self._unsubscribeEvents()
-            
+
         return ret
-        
+
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # API for attribute configuration
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-    
+    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
-    def setConfigEx(self,config):
+    def setConfigEx(self, config):
         self.getParentObj().set_attribute_config([config])
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
-    # PyTango event handling (private) 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-    
+    # PyTango event handling (private)
+    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
     def isUsingEvents(self):
         return self.__subscription_state == SubscriptionState.Subscribed
@@ -392,12 +397,12 @@ class TangoAttribute(TaurusAttribute):
     def _subscribeEvents(self):
         """ Enable subscription to the attribute events. If change events are 
             not supported polling is activated """
-        
-        # We have to register for configuration events before registering for 
-        # change events because when a change event occurs we need to have 
+
+        # We have to register for configuration events before registering for
+        # change events because when a change event occurs we need to have
         # configuration info in order to know how to decode the value
         self._getRealConfig().addListener(self)
-        
+
 
         self.trace("Subscribing to change events...")
 
@@ -417,17 +422,17 @@ class TangoAttribute(TaurusAttribute):
             self.__chg_evt_id = dev.subscribe_event(self.getSimpleName(),
                                                   PyTango.EventType.CHANGE_EVENT,
                                                   self, [])
-            
+
         except:
             self.__subscription_state = SubscriptionState.PendingSubscribe
             self._activatePolling()
             self.__chg_evt_id = dev.subscribe_event(self.getSimpleName(),
                                                   PyTango.EventType.CHANGE_EVENT,
                                                   self, [], True)
-    
+
     def _unsubscribeEvents(self):
         # Careful in this method: This is intended to be executed in the cleanUp
-        # so we should not access external objects from the factory, like the 
+        # so we should not access external objects from the factory, like the
         # parent object
         self._getRealConfig().removeListener(self)
         if not self.__chg_evt_id is None and not self._dev_hw_obj is None:
@@ -445,11 +450,11 @@ class TangoAttribute(TaurusAttribute):
                     self.trace(str(df))
         self._deactivatePolling()
         self.__subscription_state = SubscriptionState.Unsubscribed
-    
+
     def push_event(self, event):
         """Method invoked by the PyTango layer when a change event occurs.
            Default implementation propagates the event to all listeners."""
-        
+
         curr_time = time.time()
         manager = Manager()
         sm = self.getSerializationMode()
@@ -469,6 +474,7 @@ class TangoAttribute(TaurusAttribute):
         elif event.errors[0].reason in EVENT_TO_POLLING_EXCEPTIONS:
             if self.isPollingActive():
                 return
+            self.info("Activating polling. Reason: %s", event.errors[0].reason)
             self.__subscription_state = SubscriptionState.PendingSubscribe
             self._activatePolling()
         else:
@@ -500,12 +506,12 @@ class TangoAttributeEventListener(EventListener):
     Note: Since this class stores for each event value the last timestamp when
     it occured, it should only be used for events for which the event value
     domain (possible values) is limited and well known (ex: an enum)"""
-    
+
     def __init__(self, attr):
         EventListener.__init__(self)
         self.attr = attr
         attr.addListener(self)
-        
+
     def eventReceived(self, s, t, v):
         if t not in (TaurusEventType.Change, TaurusEventType.Periodic):
             return
@@ -517,9 +523,9 @@ def test1():
     import numpy
     from taurus import Attribute
     a = Attribute('sys/tg_test/1/ulong64_scalar')
-    
+
     a.write(numpy.uint64(88))
 
 if __name__ == "__main__":
     test1()
-    
+
