@@ -34,7 +34,7 @@ __all__ = ["TaurusConsoleFactory"]
 __docformat__ = 'restructuredtext'
 
 from taurus.core.util.singleton import Singleton
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 
 from taurusconsolewidget import TaurusConsoleWidget
 from taurusconsolewindow import TaurusConsoleWindow
