@@ -34,7 +34,7 @@ __docformat__ = 'restructuredtext'
 import os
 import sys
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurusbasecontainer import TaurusBaseContainer
 
 from taurus.qt.qtcore.configuration import BaseConfigurableClass
@@ -798,7 +798,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         self.__helpManualURI = uri
         if self.helpManualBrowser is None:
             try:
-                from taurus.qt.QtWebKit import QWebView
+                from taurus.external.qt.QtWebKit import QWebView
                 self.helpManualBrowser = QWebView()
             except:
                 self.helpManualBrowser = Qt.QLabel('QWebkit is not available')
@@ -845,7 +845,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
             username = getSystemUserName()
             appname = unicode(Qt.QApplication.applicationName())
             key = "__socket_%s-%s__"%(username,appname)
-        from taurus.qt import QtNetwork       
+        from taurus.external.qt import QtNetwork
         socket = QtNetwork.QLocalSocket(self) 
         socket.connectToServer(key)
         alive = socket.waitForConnected(3000)
@@ -857,11 +857,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
             self.connect(self.socketServer, Qt.SIGNAL("newConnection()"), self.onIncommingSocketConnection)
             ok = self.socketServer.listen(key)
             if not ok:
-                try:
-                    AddressInUseError = Qt.QAbstractSocket.AddressInUseError #This fails in some PyQt4 versions...
-                except:
-                    from PyQt4.QtNetwork import QAbstractSocket #...so we try this other way of accessing
-                    AddressInUseError = QAbstractSocket.AddressInUseError 
+                AddressInUseError = QtNetwork.QAbstractSocket.AddressInUseError
                 if self.socketServer.serverError() == AddressInUseError:
                     self.info('Resetting unresponsive socket with key "%s"',key)
                     if hasattr(self.socketServer, 'removeServer'): #removeServer() was added in Qt4.5. (In Qt4.4 a call to listen() removes a previous server)  
