@@ -35,7 +35,7 @@ import operator
 import PyTango
 
 from taurus.core.taurusbasetypes import TaurusElementType, TaurusEventType
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.qt.qtgui.base import TaurusBaseWidget
 from taurus.qt.qtgui.base import TaurusBaseController
 from taurus.qt.qtgui.base import TaurusScalarAttributeControllerHelper
