@@ -32,6 +32,6 @@ try:
 except:
     from taurus.qt.qtgui.display import create_fallback as __create
     TaurusQubDataImageDisplay = __create("TaurusQubDataImageDisplay")
-    import taurus.core.util
-    _logger = taurus.core.util.Logger(__name__)
+    import taurus.core.util.log
+    _logger = taurus.core.util.log.Logger(__name__)
     _logger.debug("Qub widgets could not be initialized", exc_info=1)
