@@ -29,17 +29,17 @@ RawDataChooser.py:  widget for importing RawData (from file or from a function)
 
 import numpy
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.core.util.safeeval import SafeEvaluator
-
-from .ui import ui_RawDataChooser
+from taurus.qt.qtgui.util.ui import UILoadable
 
 
-class QRawDataWidget(Qt.QWidget, ui_RawDataChooser.Ui_RawDataChooser):
+@UILoadable
+class QRawDataWidget(Qt.QWidget):
     
     def __init__(self, parent=None):
         super(QRawDataWidget,self).__init__(parent)
-        self.setupUi(self)
+        self.loadUi()
 
         #connecttions
         self.connect(self.openFilesBT,Qt.SIGNAL( "clicked()"), self.onOpenFilesButtonClicked)
@@ -76,7 +76,7 @@ class QRawDataWidget(Qt.QWidget, ui_RawDataChooser.Ui_RawDataChooser):
         
 if __name__ == "__main__":
     import sys 
-    app = QApplication(sys.argv)
+    app = Qt.QApplication(sys.argv)
     form = QRawDataWidget()
     form.show()
     sys.exit(app.exec_())
