@@ -29,7 +29,7 @@ AttributeChooser.py: widget for choosing (a list of) attributes from a tango DB
 
 
 import sys
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 import taurus.core
 from taurus.qt.qtgui.container import TaurusWidget
 from taurus.qt.qtgui.tree import TaurusDbTreeWidget
