@@ -27,7 +27,7 @@
 monitor.py: Specialized mini-trend widget to monitor some scalar value
 """
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.qt.qtgui.plot import TaurusTrend
 
 
