@@ -33,7 +33,7 @@ __all__=["DateTimeScaleEngine", "DeltaTimeScaleEngine", "FixedLabelsScaleEngine"
 import numpy
 from datetime import datetime, timedelta
 from time import mktime
-from taurus.qt import Qt, Qwt5
+from taurus.external.qt import Qt, Qwt5
 
     
 def _getDefaultAxisLabelsAlignment(axis, rotation):
